cordova.define("gfpush.gfpush", function(require, exports, module) {
var GfPush = function(){
    this.debug = false;
};

GfPush.prototype.callNative = function(name, args, callback) {
    if (this.debug) {
        if (callback) {
            console.log("\nGfPush callnative: " + name + " args: " + JSON.stringify(args) + "\n");
            return cordova.exec(callback, callback, 'GfPush', name, args);
        } else {
            var successCallback = function() {
                console.error("\nGfPush callNative: " + name + " args: " + JSON.stringify(args) + "\nOK:" + JSON.stringify(arguments) + "\n");
            };
            var errorCallback = function() {
                console.error("\nGfPush callNative: " + name + " args: " + JSON.stringify(args) + "\nError:" + JSON.stringify(arguments) + "\n");
            };
            return cordova.exec(successCallback, errorCallback, 'GfPush', name, args);
        }
    } else {
        if (callback) {
            return cordova.exec(callback, callback, 'GfPush', name, args);
        } else {
            var callback = function() {
                console.error("\nGfPush callNative: " + name + " args: " + JSON.stringify(args) + "\nError:" + JSON.stringify(arguments) + "\n");
            };
            return cordova.exec(function(){}, callback, 'GfPush', name, args);
        }
    }
};

/**
 * Set Debug Log On/Off
 *
 * @param {debug} true/false
 * @return {Push}
 * @api public
 */
GfPush.prototype.SetDebug = function(debug) {
    this.debug = debug;
    return this.callNative("setDebug", [debug]);
};

/**
 * Echo mesage, by native module
 *
 * @param {word} the message
 * @return {Push}
 * @api public
 */
GfPush.prototype.Echo = function(word,cb) {
    return this.callNative("echo",[word],cb);
};

//启动
GfPush.prototype.StartService = function(config, appid, clientkey) {
    return this.callNative("startService", [config, appid, clientkey]);
};

//是否已启用消息推送
GfPush.prototype.IsEnable = function(cb) {
    return this.callNative("isEnable",[],cb);
};

//读取推送通道信息
GfPush.prototype.GetPushInfo = function(cb) {
    return this.callNative("getPushInfo", [], cb);
};

//是否启用声音
GfPush.prototype.GetSound = function(cb) {
    return this.callNative("getSound",[],cb);
};

//是否启用振动
GfPush.prototype.GetVibrate = function(cb) {
    return this.callNative("getVibrate",[],cb);
};

//获取通知是否开启
GfPush.prototype.IsNotificationEnable = function(cb) {
    return this.callNative("isNotificationEnable",[],cb);
};

//弹出通知开启对话框
GfPush.prototype.EnsureNotificationEnable = function() {
    return this.callNative("ensureNotificationEnable",[]);
};

//是否应该弹出通知开启对话框
GfPush.prototype.ShouldPopupAutoStartup = function(cb) {
    return this.callNative("shouldPopupAutoStartup",[],cb);
};

//检查应该弹出自启动设置框
GfPush.prototype.PopupAutoStartupSetting = function() {
    return this.callNative("popupAutoStartupSetting",[]);
};

//弹出自启动设置框
GfPush.prototype.SetSoundVibrate = function(s, v) {
    return this.callNative("setSoundVibrate", [s, v]);
};

//获取注册id
GfPush.prototype.GetRegId = function(cb){
    return this.callNative("getRegId",[],cb);
};

//获取Uid
GfPush.prototype.GetUid = function(cb){
    return this.callNative("getUid",[],cb);
};

//获取推送通道
GfPush.prototype.GetChannel = function(cb){
    return this.callNative("getChannel",[],cb);
};

//绑定用户UID
GfPush.prototype.BindUser = function(uid){
    return this.callNative("bindUser",[uid]);
};

//解除绑定UID
GfPush.prototype.UnbindUser = function(){
    return this.callNative("unbindUser",[]);
};

//设置badage数量
GfPush.prototype.SetBadge = function(num){
    return this.callNative("setBadge",[num]);
};

//更改badage数量
GfPush.prototype.UpdateBadge = function(num){
    return this.callNative("updateBadge",[num]);
};

//获取badge数量
GfPush.prototype.GetBadge = function(cb){
    return this.callNative("getBadge",[]);
};

//设置标签
GfPush.prototype.SetTag = function(tag,value){
    return this.callNative("setTag",[tag,value]);
};

//删除标签
GfPush.prototype.UnsetTag = function(tag){
    return this.callNative("unsetTag",[tag]);
};

//设置语言
GfPush.prototype.SetLanguage = function(lang){
    return this.callNative("setLanguage",[lang]);
};

//解除绑定UID
GfPush.prototype.StopService = function(){
    return this.callNative("stopService",[]);
};

//读取所有消息条数
GfPush.prototype.GetAllCount = function(cb){
    return this.callNative("getAllCount",[],cb);
};

//读取所有消息
GfPush.prototype.GetAllMessages = function(offset, pagesize, cb){
    return this.callNative("getAllMessages",[offset, pagesize],cb);
};

//读取未读消息条数
GfPush.prototype.GetUnreadCount = function(cb){
    return this.callNative("getUnreadCount",[],cb);
};

//读取未读消息
GfPush.prototype.GetUnreadMessages = function(offset, pagesize, cb){
    return this.callNative("getUnreadMessages",[offset, pagesize],cb);
};

//设置消息为已读
GfPush.prototype.ReadMessage = function(mid){
    return this.callNative("readMessage",[mid]);
};

GfPush.prototype.addEventListener = function(event, fn){
    this._callbacks = this._callbacks || Object.create(null);
    (this._callbacks[event] = this._callbacks[event] || [])
        .push(fn);
    return this;
};

GfPush.prototype.on = GfPush.prototype.addEventListener;

/**
 * Adds an `event` listener that will be invoked a single
 * time then automatically removed.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Push}
 * @api public
 */
GfPush.prototype.once = function(event, fn){
    function on() {
        this.off(event, on);
        fn.apply(this, arguments);
    }

    on.fn = fn;
    this.on(event, on);
    return this;
};

/**
 * Remove the given callback for `event` or all
 * registered callbacks.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Push}
 * @api public
 */
GfPush.prototype.removeEventListener = function(event, fn){
    this._callbacks = this._callbacks || Object.create(null);

    // all
    if (0 == arguments.length) {
        this._callbacks = Object.create(null);
        return this;
    }

    // specific event
    var callbacks = this._callbacks[event];
    if (!callbacks) return this;

    // remove all handlers
    if (1 == arguments.length) {
        delete this._callbacks[event];
        return this;
    }

    // remove specific handler
    var cb;
    for (var i = 0; i < callbacks.length; i++) {
        cb = callbacks[i];
        if (cb === fn || cb.fn === fn) {
            callbacks.splice(i, 1);
            break;
        }
    }

    // Remove event specific arrays for event types that no
    // one is subscribed for to avoid memory leak.
    if (callbacks.length === 0) {
        delete this._callbacks[event];
    }

    return this;
};

GfPush.prototype.off = GfPush.prototype.removeEventListener;

/**
 * Emit `event` with the given args.
 *
 * @param {String} event
 * @param {Mixed} ...
 * @return {Push}
 */
GfPush.prototype.emit = function(event){
    this._callbacks = this._callbacks || Object.create(null);

    var args = new Array(arguments.length - 1);
    var callbacks = this._callbacks[event];

    for (var i = 1; i < arguments.length; i++) {
        args[i - 1] = arguments[i];
    }

    if (callbacks) {
        callbacks = callbacks.slice(0);
        for (var i = 0, len = callbacks.length; i < len; ++i) {
            callbacks[i].apply(this, args);
        }
    }

    return this;
};

/**
 * Return array of callbacks for `event`.
 *
 * @param {String} event
 * @return {Array}
 * @api public
 */
GfPush.prototype.listeners = function(event){
    this._callbacks = this._callbacks || Object.create(null);
    return this._callbacks[event] || [];
};

/**
 * Check if this emitter has `event` handlers.
 *
 * @param {String} event
 * @return {Boolean}
 * @api public
 */
GfPush.prototype.hasListeners = function(event){
    return !! this.listeners(event).length;
};

/**
 * Returns an array listing the events for which the emitter has registered listeners.
 *
 * @return {Array}
 * @api public
 */
GfPush.prototype.eventNames = function(){
    return this._callbacks ? Object.keys(this._callbacks) : [];
};

module.exports = new GfPush();

if (!window.plugins) {
    window.plugins = {};
}

if (!window.plugins.GfPush) {
    window.plugins.GfPush = module.exports;
}

});
